Learn R Programming

ProPublicaR (version 1.1.4)

compare_two_member_bill_sponsorships: Compare Two Members’ Bill Sponsorships

Description

To compare bill sponsorship between two members who served in the same Congress and chamber. HTTP Request: GET https://api.propublica.org/congress/v1/members/first-member-id/bills/second-member-id/congress/chamber.json

Usage

compare_two_member_bill_sponsorships(
  first_member_id,
  second_member_id,
  congress,
  chamber,
  page = 1,
  myAPI_Key
)

Value

List of bill sponsorship comparison between two members who served in the same Congress and chamber

Arguments

first_member_id

The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.

second_member_id

The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.

congress

102-116 for House, 101-116 for Senate

chamber

house o senate

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
compare_two_member_bill_sponsorships('G000575', 'D000624', '114', 'house')
}

Run the code above in your browser using DataLab