get_bills_cosponsored_member: Get Bills Cosponsored by a Specific Member
Description
To get the 20 most recent bill cosponsorships for a particular member, either bills cosponsored or bills where cosponsorship was withdrawn. #HTTP Request: GET https://api.propublica.org/congress/v1/members/member-id/bills/type.json
List of returned JSON from endpoint that retrieves the 20 most recent bill cosponsorships for a particular member
Arguments
member_id
The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.
type
cosponsored or withdrawn
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.