powered by
https://www.propublica.org/datastore/apis HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/search
get_candidate_by_name(NAME, cycle = 2018, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves federal candidates by last name, using a query string parameter.
The first or last name of the candidate.
The election cycle
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_candidate_by_name('Wilson', 2016) }
Run the code above in your browser using DataLab