Learn R Programming

ProPublicaR (version 1.1.4)

get_committee_by_name: Get Committee by name

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/search

Usage

get_committee_by_name(NAME, cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves ca specific committee by name for a given campaign cycle from the campaign-finance API from ProPublica.

Arguments

NAME

The name of the committee.

cycle

The election cycle

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_committee_by_name('Americans FOR A BETTER TOMORROW TODAY', 2016)
}

Run the code above in your browser using DataLab