Learn R Programming

ProPublicaR (version 1.1.4)

get_committee_filings: Get Committee Filings

Description

HTTP Request GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id/filings

Usage

get_committee_filings(FEC_ID, cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent FEC filings from the specified committee. Electronic filings are available back to 2001. Paper filings by Senate candidate committees and senatorial party committees go back to 1999.

Arguments

FEC_ID

The FEC-assigned 9-character ID of a committee.

cycle

The election cycle

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_committee_filings('C00553560', 2016)
}

Run the code above in your browser using DataLab