Learn R Programming

ProPublicaR (version 1.1.4)

get_committee_leadership: Get Leadership Committees

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/leadership

Usage

get_committee_leadership(cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves committees designated as “leadership PACs” by the FEC from the campaign-finance API from ProPublica.

Arguments

cycle

The election cycle: an even-numbered year between 1996 and 2016. The current cycle in 2018

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_committee_leadership(2016)
}

Run the code above in your browser using DataLab