Learn R Programming

ProPublicaR (version 1.1.4)

get_congressional_statement_by_bill: Get Congressional Statements by Bill

Description

To get lists of statements published on a specific member’s congressional website during a particular congress, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/bills/bill-id/statements.json

Usage

get_congressional_statement_by_bill(congress, bill_id, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results and supports pagination using multiples of 20.

Arguments

congress

113-116

bill_id

a bill slug, for example s19 - these can be found in bill responses.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_congressional_statement_by_bill(115, 's19')
}

Run the code above in your browser using DataLab