Learn R Programming

ProPublicaR (version 1.1.4)

get_electioneering_communications_by_date: Get Electioneering Communications by Date

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/electioneering_communications/year/month/day

Usage

get_electioneering_communications_by_date(
  cycle = 2018,
  year,
  month,
  day,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves all broadcast advertisements that identify one or more federal candidates (and have aired 30 days before a primary election and 60 days before the general election) from a specific date.

Arguments

cycle

The election cycle

year

The four-digit year from 2008-2016.

month

The two-digit month from 01-12

day

The two-digit day from 01-31

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_electioneering_communications_by_date(2016, 2012, '10', '01')
}

Run the code above in your browser using DataLab