Learn R Programming

ProPublicaR (version 1.1.4)

get_electioneering_communications_committee: Get Electioneering Communications by Specific Committee

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id/electioneering_communications

Usage

get_electioneering_communications_committee(
  cycle = 2018,
  FEC_ID,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the most recent broadcast advertisements by a specific committee that identify one or more federal candidates (and have aired 30 days before a primary election and 60 days before the general election).

Arguments

cycle

The election cycle

FEC_ID

The FEC-assigned 9-character ID of a committee. To find a committee official FEC ID, use a candidate search request or the FEC web site.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_electioneering_communications_committee(2016, 'C30002034')

}

Run the code above in your browser using DataLab