Learn R Programming

ProPublicaR (version 1.1.4)

get_electronic_filing_by_committees: Search for Electronic Filings by committee name o partial name

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/filings/search

Usage

get_electronic_filing_by_committees(NAME, cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves information about FEC reports filed electronically by a committee for a given campaign cycle from the campaign-finance API from ProPublica.

Arguments

NAME

The committee name or partial name

cycle

The election cycle

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_electronic_filing_by_committees(NAME = "UNITED EGG", 2016)
}

Run the code above in your browser using DataLab