Learn R Programming

ProPublicaR (version 1.1.4)

get_hearing_specific_committee: Get Hearings for a Specific Committee

Description

To get a list of 20 upcoming Senate or House committee meetings, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/committees/committee-id/hearings.json

Usage

get_hearing_specific_committee(
  congress,
  chamber,
  committee_id,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent hearings and supports pagination.

Arguments

congress

114-116

chamber

house or senate

committee_id

Optional committee abbreviation, for example HSAG. Use the full committees response to find abbreviations.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_hearing_specific_committee(115, 'house', 'HSRU')
get_hearing_specific_committee(115, 'house', 
lists_of_committees(115, "senate")$results[[1]]$committees[[1]]$id)
}

Run the code above in your browser using DataLab