Learn R Programming

ProPublicaR (version 1.1.4)

get_independent_expenditure_by_committee: Get Independent Expenditures by Specific Committee

Description

#HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id/independent_expenditures

Usage

get_independent_expenditure_by_committee(
  cycle = 2018,
  FEC_ID,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent independent expenditures by a given committee.

Arguments

cycle

The election cycle

FEC_ID

The FEC-assigned 9-character ID of a committee. To find a committee official FEC ID, use a candidate search request or the FEC web site.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_independent_expenditure_by_committee(2016, FEC_ID ='C00575423')
}

Run the code above in your browser using DataLab