Learn R Programming

ProPublicaR (version 1.1.4)

get_independent_expenditure_by_date: Get Independent Expenditures by Date

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/independent_expenditures/year/month/day

Usage

get_independent_expenditure_by_date(
  cycle = 2018,
  year,
  month,
  day,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves all independent expenditures on a specific date (the date of activity, not the date filed with the FEC).

Arguments

cycle

The election cycle

year

The four-digit year from 2008-2016

month

The two-digit month from 01-12

day

The two-digit day from 01-31

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_independent_expenditure_by_date(2016, year = 2018, month ='01', day = '01')
}

Run the code above in your browser using DataLab