Learn R Programming

ProPublicaR (version 1.1.4)

get_independent_expenditure_race_totals_committee: Get Independent Expenditure Office Totals

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id/independent_expenditures/races

Usage

get_independent_expenditure_race_totals_committee(
  cycle,
  FEC_ID,
  page = 1,
  myAPI_Key
)

Value

list of returned JSON from endpoint that retrieves the total amounts of money that a given committee has spent on individual races (consisting of a state, office and district) during a cycle.

Arguments

cycle

The election cycle

FEC_ID

The FEC-assigned 9-character ID of a committee

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_independent_expenditure_race_totals_committee(2016, 'C00490375')
}

Run the code above in your browser using DataLab