List of returned JSON from endpoint that retrieves the 200 most recent independent expenditures in support of or opposition to any presidential candidate.
Arguments
cycle
The election cycle
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.