Learn R Programming

ProPublicaR (version 1.1.4)

get_lobbyist_bundlers: Get Lobbyist Bundlers for a Specific Committee

Description

Committees must report registered lobbyists who act as “bundlers”, collecting donations for the committee from multiple contributors. HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id/lobbyist_bundlers

Usage

get_lobbyist_bundlers(cycle = 2018, FEC_ID, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the most recent lobbyist bundlers reported by a specific committee.

Arguments

cycle

The election cycle

FEC_ID

The FEC-assigned 9-character ID of a committee. To find a committee’s official FEC ID, use a committee search request or the FEC web site.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_lobbyist_bundlers(2016, 'C00579458')
}

Run the code above in your browser using DataLab