Learn R Programming

ProPublicaR (version 1.1.4)

get_member_vote_position: Get a Specific Member’s Vote Positions

Description

To get the most recent vote positions for a specific member of the House of Representatives or Senate. HTTP Request: GET https://api.propublica.org/congress/v1/members/member-id/votes.json

Usage

get_member_vote_position(member_id, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the most recent vote positions for a specific member of the House of Representatives or Senate

Arguments

member_id

The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_member_vote_position('K000388')
}

Run the code above in your browser using DataLab