Learn R Programming

ProPublicaR (version 1.1.4)

get_members_leaving: Get Members Leaving Office

Description

To get a list of members who have left the Senate or House or have announced plans to do so. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/members/leaving.json

Usage

get_members_leaving(congress, chamber, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves a list of members who have left the Senate or House

Arguments

congress

111-116

chamber

house or senate

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_members_leaving(115, 'house')
}

Run the code above in your browser using DataLab