Learn R Programming

ProPublicaR (version 1.1.4)

get_new_members: Get New Members

Description

To get a list of the most recent new members of the current Congress. HTTP Request: GET https://api.propublica.org/congress/v1/members/new.json

Usage

get_new_members(page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves a list of the most recent new members of the current Congress

Arguments

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_new_members()
}

Run the code above in your browser using DataLab