Learn R Programming

ProPublicaR (version 1.1.4)

get_nominees_by_state: Get Nominees by State

Description

To get a list of presidential civilian nominations of individuals from a specific state, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/nominees/state/state.json

Usage

get_nominees_by_state(congress, state, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves

Arguments

congress

107-116

state

Two-letter state abbreviation

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_nominees_by_state(115, 'VA')
}

Run the code above in your browser using DataLab