Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_amendments: Get Recent Amendments

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/filings/amendments

Usage

get_recent_amendments(cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the most recent filings that are amendments of earlier filings

Arguments

cycle

The election cycle

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_amendments(2016)
}

Run the code above in your browser using DataLab