Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_committee_hearing: Get Recent Committee Hearings

Description

To get a list of 20 upcoming Senate or House committee meetings, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/committees/hearings.json

Usage

get_recent_committee_hearing(congress, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results and supports pagination using multiples of 20.

Arguments

congress

114-116

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_committee_hearing(115)
}

Run the code above in your browser using DataLab