Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_congressional_statements: Get Recent Congressional Statements

Description

To get lists of recent statements published on congressional websites, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/statements/latest.json

Usage

get_recent_congressional_statements(page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results and supports pagination using multiples of 20.

Arguments

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_congressional_statements()
}

Run the code above in your browser using DataLab