get_recent_congressional_statements_by_date: Get Congressional Statements by Date
Description
To get lists of statements published on congressional websites on a particular date, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/statements/date/date.json