get_recent_congressional_statements_by_term: Get Congressional Statements by Search Term
Description
To get lists of statements published on congressional websites using a search term, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/statements/search.json?query=term
List of returned JSON from endpoint that retrieves the 20 most recent results that contain the search term in the title or body of the statement and supports pagination using multiples of 20.
Arguments
term
search term
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.