Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_electioneering_communications: Get Recent Electioneering Communications

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/electioneering_communications

Usage

get_recent_electioneering_communications(cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent broadcast advertisements that identify one or more federal candidates (and have aired 30 days before a primary election and 60 days before the general election).

Arguments

cycle

The election cycle

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_electioneering_communications(2016)

}

Run the code above in your browser using DataLab