@return List of returned JSON from endpoint that retrieves the 200 most recent independent expenditures and optionally can be offset by multiples of 20.
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.