Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_late_contributions: Get Recent Late Contributions https://www.propublica.org/datastore/apis HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/contributions/48hour

Description

Get Recent Late Contributions https://www.propublica.org/datastore/apis HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/contributions/48hour

Usage

get_recent_late_contributions(cycle = 2018, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the most recent late contributions to candidates from the campaign-finance API from ProPublica.

Arguments

cycle

The election cycle. Cycle must be even-numbered year between 2010 and 2018

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_late_contributions(2016)
}

Run the code above in your browser using DataLab