Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_late_contributions_candidate: Get Recent Late Contributions to a Specific Candidate https://www.propublica.org/datastore/apis HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/fec-id/48hour

Description

Get Recent Late Contributions to a Specific Candidate https://www.propublica.org/datastore/apis HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/fec-id/48hour

Usage

get_recent_late_contributions_candidate(
  cycle = 2018,
  FEC_ID,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the most recent late contributions to candidates from the campaign-finance API from ProPublica.

Arguments

cycle

The election cycle

FEC_ID

The FEC-assigned 9-character ID of a candidate.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_late_contributions_candidate(2016, 'H4NY11138')
}

Run the code above in your browser using DataLab