Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_late_contributions_date: Get Recent Late Contributions by Date

Description

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/contributions/48hour/year/month/day

Usage

get_recent_late_contributions_date(
  cycle = 2018,
  year,
  month,
  day,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves late contributions from a specific dates for a given campaign cycle from the campaign-finance API from ProPublica.

Arguments

cycle

The election cycle

year

The four-digit year from 2010-2018, match cycle

month

The two-digit month from 01-12

day

The two-digit day from 01-31

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_late_contributions_date(2016, year = 2016, month = '09', day = '07')
}

Run the code above in your browser using DataLab