Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_lobbying_representation_filings: Get Recent Lobbying Representation filings

Description

To get the 20 most recent lobbying representation filings, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/lobbying/latest.json

Usage

get_recent_lobbying_representation_filings(page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent lobbying representation filings.

Arguments

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_lobbying_representation_filings()
}

Run the code above in your browser using DataLab