Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_nominations_by_category: Get Recent Nominations by Category

Description

To get lists of presidential nominations for civilian positions,, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/nominees/type.json

Usage

get_recent_nominations_by_category(congress, type, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results for the specified type: received, updated, confirmed or withdrawn.

Arguments

congress

107-116

type

received, updated, confirmed, withdrawn

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_nominations_by_category(115, 'confirmed')
}

Run the code above in your browser using DataLab