Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_official_communications_by_category: Get Recent Official Communications by Category

Description

Get lists of official communications to Congress from the president, executive branch agencies and state legislatures to congressional committees.

Usage

get_recent_official_communications_by_category(
  congress,
  category,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results for the specified type: ec (Executive Communication), pm (Presidential Message) or pom (Petition or Memorial).

Arguments

congress

114-116 for House, 96-116 for Senate

category

ec, pm, pom

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_official_communications_by_category(115, 'pm')
}

Run the code above in your browser using DataLab