Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_official_communications_by_date: Get Recent Official Communications by Date

Description

o get lists of official communications to Congress on a specific date, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/communications/category/category.json

Usage

get_recent_official_communications_by_date(
  year,
  month,
  day,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent results for the specified type: ec (Executive Communication), pm (Presidential Message) or pom (Petition or Memorial).

Arguments

year

yyyy format

month

mm format

day

dd format

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_official_communications_by_date(2018, '03', '21')
}

Run the code above in your browser using DataLab