Learn R Programming

ProPublicaR (version 1.1.4)

get_recent_personal_explanations_specific_member: Get Recent Personal Explanations by a Specific Members

Description

Lawmakers, mostly in the House but also in the Senate, can make personal explanations for missed or mistaken votes in the Congressional Record. HTTP Request: GET https://api.propublica.org/congress/v1/members/member_id/explanations/congress.json

Usage

get_recent_personal_explanations_specific_member(
  member_id,
  congress,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent personal explanations by a specific member in the specified Congress, and supports paginated requests using multiples of 20.

Arguments

member_id

The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.

congress

110-116

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recent_personal_explanations_specific_member('S001193', 115)
}

Run the code above in your browser using DataLab