Learn R Programming

ProPublicaR (version 1.1.4)

get_recently_candidates: Get Top 20 Candidates in Specific Financial Category

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/new (https://www.propublica.org/datastore/apis)

Description

Get Top 20 Candidates in Specific Financial Category

HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/new (https://www.propublica.org/datastore/apis)

Usage

get_recently_candidates(cycle = 2018, page = 1, myAPI_Key)

Value

List of the most recently added FEC candidates for a given campaign cycle from the campaign-finance API from ProPublica.

Arguments

cycle

The election cycle: Four-digit even-numbered year between 2010 and 2018

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_recently_candidates(2016)
}

Run the code above in your browser using DataLab