Learn R Programming

ProPublicaR (version 1.1.4)

get_senate_nomination_votes: Get Senate Nomination Votes

Description

To get Senate votes on presidential nominations. HTTP Request: GET https://api.propublica.org/congress/v1/congress/nominations.json

Usage

get_senate_nomination_votes(congress, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves Senate votes on presidential nominations

Arguments

congress

101-116

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_senate_nomination_votes(114)
}

Run the code above in your browser using DataLab