Learn R Programming

ProPublicaR (version 1.1.4)

get_specific_bill_subject: Get a Specific Bill Subject

Description

Use this request type to search for bill subjects that contain a specified term. HTTP Request: GET https://api.propublica.org/congress/v1/bills/subjects/search.json

Usage

get_specific_bill_subject(subject, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves bill subjects that contain a specified term.

Arguments

subject

a word or phrase to search

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_specific_bill_subject('meat')
}

Run the code above in your browser using DataLab