Learn R Programming

ProPublicaR (version 1.1.4)

get_specific_lobbying_representation_filings: Get a Specific Lobbying Representation filing

Description

To get a specific lobbying representation filing, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/lobbying/id.json

Usage

get_specific_lobbying_representation_filings(id, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves

Arguments

id

numeric id attribute from search or latest responses

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_specific_lobbying_representation_filings('300986302')
}

Run the code above in your browser using DataLab