Learn R Programming

ProPublicaR (version 1.1.4)

get_specific_subcommittee: Get a Specific Subcommittee

Description

To get information about a single Senate or House subcommittee, including the members of that subcommittee, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/committees/committee-id/subcommittees/subcommittee-id.json

Usage

get_specific_subcommittee(
  congress,
  chamber,
  committee_id,
  subcommittee_id,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves the 20 most recent hearings and supports pagination.

Arguments

congress

114-116

chamber

house or senate or joint

committee_id

Optional committee abbreviation, for example HSAG. Use the full committees response to find abbreviations.

subcommittee_id

Optional sub-committee abbreviation, for example HSAG. Use the full committees response to find abbreviations.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_specific_subcommittee(115, 'house', 'HSAS', 'HSAS28')
get_specific_subcommittee(115, 'house', 
lists_of_committees(115, "senate")$results[[1]]$committees[[2]]$id,
lists_of_committees(115, "senate")$results[[1]]$committees[[2]]$subcommittees[[1]]$id)
}

Run the code above in your browser using DataLab