Learn R Programming

ProPublicaR (version 1.1.4)

get_votes_by_date: Get Votes by Date

Description

HTTP Requests: GET https://api.propublica.org/congress/v1/chamber/votes/year/month.json

Usage

get_votes_by_date(
  chamber = c("house", "senate"),
  year,
  month,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves all votes for one or both chambers in a particular month s

Arguments

chamber

house or senate

year

YYYY format

month

MM format

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_votes_by_date('house', 2018, '09')
}

Run the code above in your browser using DataLab