Learn R Programming

ProPublicaR (version 1.1.4)

get_votes_by_date_range: Get Votes by date range

Description

HTTP Requests: GET https://api.propublica.org/congress/v1/chamber/votes/start-date/end-date.json

Usage

get_votes_by_date_range(
  chamber = c("house", "senate"),
  start_date,
  end_date,
  page = 1,
  myAPI_Key
)

Value

List of returned JSON from endpoint that retrieves all votes in a particular date range (fewer than 30 days) s

Arguments

chamber

house or senate

start_date

YYYY-MM-DD format

end_date

YYYY-MM-DD format

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
get_votes_by_date_range('house', '2017-01-03', '2017-01-31')
}

Run the code above in your browser using DataLab