Learn R Programming

ProPublicaR (version 1.1.4)

list_members_chamber_congress: To get a list of members of a particular chamber in a particular Congress

Description

The results include all members who have served in that congress and chamber, including members who are no longer in office. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/members.json

Usage

list_members_chamber_congress(congress, chamber, page = 1, myAPI_Key)

Value

list of members of a particular chamber in a particular Congress

Arguments

congress

102-118 for House, 80-118 for Senate

chamber

house or senate

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
list_members_chamber_congress(115, 'senate')
}

Run the code above in your browser using DataLab