Learn R Programming

ProPublicaR (version 1.1.4)

recent_bills_by_member: Get Recent Bills by a Specific Member

Description

Use this request type to get the 20 bills most recently introduced or updated by a particular member. Results can include more than one Congress. HTTP Request: GET https://api.propublica.org/congress/v1/members/member-id/bills/type.json

Usage

recent_bills_by_member(member_id, type, page = 1, myAPI_Key)

Value

the 20 bills most recently introduced or updated by a particular member. Results can include more than one Congress.

Arguments

member_id

member-id The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.

type

introduced or updated

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
recent_bills_by_member('L000287', 'introduced')
}

Run the code above in your browser using DataLab