Learn R Programming

ProPublicaR (version 1.1.4)

recent_bills_by_subject: Get Recent Bills by a Specific Subject

Description

Use this request type to get the 20 most recently updated bills for a specific legislative subject. Results can include more than one Congress. HTTP Request: GET https://api.propublica.org/congress/v1/bills/subjects/subject.json

Usage

recent_bills_by_subject(subject, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves the 20 most recently updated bills for a specific legislative subject.

Arguments

subject

A slug version of a legislative subject, displayed as url_name in subject responses.

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
recent_bills_by_subject('meat')
}

Run the code above in your browser using DataLab