Learn R Programming

ProPublicaR (version 1.1.4)

search_lobbying_representation_filings: Search Lobbying Representation Filings

Description

Returns recent lobbying representation filings for a given search term, in batches of twenty.

Usage

search_lobbying_representation_filings(query, page = 1, myAPI_Key)

Value

List of returned JSON from endpoint that retrieves

Arguments

query

keyword or phrase

page

Results come in batches of 20. The page parameter specifies which one to retrieve.

myAPI_Key

API key from Propublica To use the congress API, you must sign up for an API key.

Examples

Run this code
if (FALSE) {
search_lobbying_representation_filings('Facebook')
}

Run the code above in your browser using DataLab