powered by
Get Committee Info HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/committees/fec-id
get_committee(FEC_ID, cycle = 2018, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves ca specific FEC committee for a given campaign cycle from the campaign-finance API from ProPublica.
The FEC-assigned 9-character ID of a committee.
The election cycle
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_committee('C00553560', 2016) }
Run the code above in your browser using DataLab