List of returned JSON from endpoint that retrieves committees designated as “leadership PACs” by the FEC from the campaign-finance API from ProPublica.
Arguments
cycle
The election cycle: an even-numbered year between 1996 and 2016. The current cycle in 2018
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.