get_congressional_statement_by_bill: Get Congressional Statements by Bill
Description
To get lists of statements published on a specific member’s congressional website during a particular congress, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/bills/bill-id/statements.json