List of returned JSON from endpoint that retrieves the 20 most recent results and supports pagination using multiples of 20.
Arguments
member_id
The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.
congress
113-116
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.