List of returned JSON from endpoint that retrieves all broadcast advertisements that identify one or more federal candidates (and have aired 30 days before a primary election and 60 days before the general election) from a specific date.
Arguments
cycle
The election cycle
year
The four-digit year from 2008-2016.
month
The two-digit month from 01-12
day
The two-digit day from 01-31
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.