List of returned JSON from endpoint that retrieves information about FEC reports filed electronically by a committee for a given campaign cycle from the campaign-finance API from ProPublica.
Arguments
NAME
The committee name or partial name
cycle
The election cycle
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.