powered by
#HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/candidates/fec-id/independent_expenditures
get_independent_expenditure_support_candidate( cycle = 2018, FEC_ID, page = 1, myAPI_Key )
List of returned JSON from endpoint that retrieves the 200 most recent independent expenditures in support of or opposition to a given candidate.
The election cycle
The FEC-assigned 9-character ID of a committee. To find a committee official FEC ID, use a candidate search request or the FEC web site.
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_independent_expenditure_support_candidate(2016, FEC_ID ='P00003392') }
Run the code above in your browser using DataLab