powered by
To get a list of members who have left the Senate or House or have announced plans to do so. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/members/leaving.json
get_members_leaving(congress, chamber, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves a list of members who have left the Senate or House
111-116
house or senate
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_members_leaving(115, 'house') }
Run the code above in your browser using DataLab