powered by
To get a list of the most recent new members of the current Congress. HTTP Request: GET https://api.propublica.org/congress/v1/members/new.json
get_new_members(page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves a list of the most recent new members of the current Congress
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_new_members() }
Run the code above in your browser using DataLab