powered by
To get a list of presidential civilian nominations of individuals from a specific state, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/nominees/state/state.json
get_nominees_by_state(congress, state, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves
107-116
Two-letter state abbreviation
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_nominees_by_state(115, 'VA') }
Run the code above in your browser using DataLab