get_quarter_office_expenses_house_member: Get Quarterly Office Expenses by a Specific House Member
Description
The House of Representatives publishes quarterly reports detailing official office expenses by lawmakers. The Congress API has data beginning in the third quarter of 2009. HTTP Request: GET https://api.propublica.org/congress/v1/members/member-id/office_expenses/year/quarter.json
the amount a given lawmaker spent during a specified year and quarter by category,
Arguments
member_id
The ID of the member to retrieve; it is assigned by the Biographical Directory of the United States Congress or can be retrieved from a member list request.l
year
2009-2017
quarter
1,2,3,4
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.