Learn R Programming

ProPublicaR (version 1.1.1)

get_races_for_state: Get all Candidates in a State for an Election Cycle

Description

Get all Candidates in a State for an Election Cycle

Usage

get_races_for_state(state, cycle = 2018)

Value

the result of the API call.

Arguments

state

The State (US) of the election

cycle

Which election cycle (e.g. 2018)

Examples

Run this code
# \donttest{
get_races_for_state('DE')
get_races_for_state('DE', 2016)
# }

Run the code above in your browser using DataLab