powered by
HTTP Request: GET https://api.propublica.org/campaign-finance/v1/cycle/filings/amendments
get_recent_amendments(cycle = 2018, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves the most recent filings that are amendments of earlier filings
The election cycle
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_recent_amendments(2016) }
Run the code above in your browser using DataLab