get_recent_official_communications_by_chamber: Get Recent Official Communications by Chamber
Description
To get lists of official communications to Congress for a specific chamber, use the following function. HTTP Request: GET https://api.propublica.org/congress/v1/congress/chamber/committees/committee-id/subcommittees/subcommittee-id.json
List of returned JSON from endpoint that retrieves the 20 most recent official communications to Congress for a specific chamber for the specified chamber, either house or senate.
Arguments
congress
114-116 for House, 96-116 for Senate
chamber
house or senate
page
Results come in batches of 20. The page parameter specifies which one to retrieve.
myAPI_Key
API key from Propublica To use the congress API, you must sign up for an API key.