powered by
To get Senate votes on presidential nominations. HTTP Request: GET https://api.propublica.org/congress/v1/congress/nominations.json
get_senate_nomination_votes(congress, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves Senate votes on presidential nominations
101-116
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_senate_nomination_votes(114) }
Run the code above in your browser using DataLab