powered by
Use this request type to search for bill subjects that contain a specified term. HTTP Request: GET https://api.propublica.org/congress/v1/bills/subjects/search.json
get_specific_bill_subject(subject, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves bill subjects that contain a specified term.
a word or phrase to search
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_specific_bill_subject('meat') }
Run the code above in your browser using DataLab