powered by
HTTP Requests: GET https://api.propublica.org/congress/v1/chamber/votes/year/month.json
get_votes_by_date( chamber = c("house", "senate"), year, month, page = 1, myAPI_Key )
List of returned JSON from endpoint that retrieves all votes for one or both chambers in a particular month s
house or senate
YYYY format
MM format
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_votes_by_date('house', 2018, '09') }
Run the code above in your browser using DataLab