powered by
HTTP Requests: GET https://api.propublica.org/congress/v1/chamber/votes/start-date/end-date.json
get_votes_by_date_range( chamber = c("house", "senate"), start_date, end_date, page = 1, myAPI_Key )
List of returned JSON from endpoint that retrieves all votes in a particular date range (fewer than 30 days) s
house or senate
YYYY-MM-DD format
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { get_votes_by_date_range('house', '2017-01-03', '2017-01-31') }
Run the code above in your browser using DataLab