powered by
Returns recent lobbying representation filings for a given search term, in batches of twenty.
search_lobbying_representation_filings(query, page = 1, myAPI_Key)
List of returned JSON from endpoint that retrieves
keyword or phrase
Results come in batches of 20. The page parameter specifies which one to retrieve.
API key from Propublica To use the congress API, you must sign up for an API key.
if (FALSE) { search_lobbying_representation_filings('Facebook') }
Run the code above in your browser using DataLab